## Launching Chromium in Docker

The simplest way:

```sh
git clone https://github.com/arno01/chromium.git
cd chromium
docker-compose run chromium
```

If it does not start, you may need to allow your user making local
connections to X server, which can be achieved with this command on host:

```sh
xhost +SI:localuser:$(id -un)
```

You can use the following shortcut function and place it to your `~/.bash_aliases` file:

```sh
function docker_helper() {
    pushd ~/docker/$1
    docker-compose rm -f "$1"
    docker-compose run -d --name "$1" "$@"
    popd
}

function chromium() {
    docker_helper "$FUNCNAME" "$@"
}
```

Then just use ``chromium`` command to launch Chromium.


## Rebuilding the image

You may want to rebuild this image on your own:

```sh
docker pull ubuntu:xenial
docker build -t andrey01/chromium .
```


## Extra Notes

Good, stable vsync and HW acceleration

```
chrome://flags/
Enable "Override software rendering list"
```

Verify

```
chrome://gpu/
```

To see whether you have the best result, you should have stable 60 FPS at following tests

```
http://ie.microsoft.com/testdrive/Performance/FishIETank/Default.html
http://www.vsynctester.com/
```


You may want to disable Google's VP8 & VP9 video codecs: "MSE & WebM VP9" and "WebM VP8"
as there is no hardware decoding for them.
To do this, install h264ify extension from

```
https://chrome.google.com/webstore/detail/h264ify/aleakchihdccplidncghkekgioiakgal?hl=en-US
```

Check the codecs

```
https://www.youtube.com/html5
```
